@@ -92,7 +92,7 @@ public:
     QV4::CompiledData::ResolvedTypeReferenceMap resolvedTypes;
     // ---
 
-    QV4::CompiledData::CompilationUnit *compile();
+    QQmlRefPointer<QV4::CompiledData::CompilationUnit> compile();
 
     QList<QQmlError> compilationErrors() const { return errors; }
     void recordError(QQmlError error);
@@ -100,6 +100,7 @@ public:
     void recordError(const QQmlCompileError &error);
 
     int registerString(const QString &str);
+    int registerConstant(QV4::ReturnedValue v);
 
     const QV4::CompiledData::Unit *qmlUnit() const;
 
